@@ -14,8 +14,7 @@ Playlist::Playlist(QWidget *parent) :
     ui->treeWidget->setColumnCount(1);
  //   ui->treeWidget->setColumnWidth(0,300);
 
-    box = new QDialogButtonBox();
-    box->setWindowTitle("Do you want to open or remove the article?");
+    box = new QDialogButtonBox(Qt::Horizontal, this);
     box->addButton("Open", QDialogButtonBox::AcceptRole);
     box->addButton("Remove", QDialogButtonBox::RejectRole );
     connect(box, SIGNAL(accepted()), this, SLOT(openArticle()));
